AppInfo class

Represents current Sendbird application information.

Annotations
  • @JsonSerializable.new(createToJson: false)

Constructors

AppInfo({required String emojiHash, required int uploadSizeLimit, required List<String> premiumFeatureList, required bool useReaction, required List<String> applicationAttributes})
AppInfo.fromJson(Map<String, dynamic> json)
factory

Properties

applicationAttributes → List<String>
list of application attributes of current application id
final
emojiHash → String
Latest hash value for emoji
final
hashCode → int
The hash code for this object.
no setterinherited
premiumFeatureList → List<String>
List of premium feature on current application id
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uploadSizeLimit → int
Uplodable file size limit (unit in bytes)
final
useReaction → bool
True if reaction feature is enabled
final

Methods

isEmojiUpdatedNeeded(String prevEmojiHash) → bool
Return true if a given prevEmojiHash is outdated
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited