Command class

Annotations
  • @JsonSerializable.new()

Constructors

Command({required String cmd, String? requestId, int? timestamp, bool? requireAuth, int? errorCode, String? errorMessage, bool replyToChannel = false, Map<String, dynamic> payload = const {}})
Command.fromJson(Map<String, dynamic> json)
factory

Properties

cmd ↔ String
getter/setter pair
errorCode → int?
final
errorMessage → String?
final
hasError → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
isAckRequired → bool
no setter
isDeletedMessage → bool
no setter
isDelivery → bool
no setter
isError → bool
no setter
isLogin → bool
no setter
isMemberCountChange → bool
no setter
isNewMessage → bool
no setter
isReaction → bool
no setter
isRead → bool
no setter
isSessionExpired → bool
no setter
isSystemEvent → bool
no setter
isThread → bool
no setter
isUpdatedMessage → bool
no setter
isUpdatedPoll → bool
no setter
isUserEvent → bool
no setter
isVote → bool
no setter
payload ↔ Map<String, dynamic>
getter/setter pair
replyToChannel ↔ bool
Retrieve whether the option includes reply to channel The Default value is false
getter/setter pair
requestId ↔ String?
getter/setter pair
requireAuth → bool?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp → int?
final

Methods

encode() → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

buildEndTyping(String channelUrl, int endAt) → Command
buildEnterChannel(BaseChannel channel) → Command
buildExitChannel(BaseChannel channel) → Command
buildFileMessage({required String channelUrl, required FileMessageParams params, required String? requestId, List? thumbnails, bool? requireAuth}) → Command
buildLOGIUpdateSessionKey(String? token) → Command
buildMessageMACK(String channelUrl, int messageId) → Command
buildPing() → Command
buildRead(String channelUrl) → Command
buildStartTyping(String channelUrl, int startAt) → Command
buildUpdateFileMessage(String channelUrl, int messageId, FileMessageParams params) → Command
buildUpdateMessageMetaArray(BaseMessage message, List<MessageMetaArray> metaArrays, MetaArrayUpdateMode updateMode, bool upsert) → Command
buildUpdateUserMessage(String channelUrl, int messageId, UserMessageParams params) → Command
buildUserMessage(String channelUrl, UserMessageParams params, String requestId) → Command
buildVotePoll({required int pollId, required List<int> pollOptionIds, required String channelUrl, required ChannelType channelType, String? requestId}) → Command
Only supports group channel