QueryInProgressError class

Inheritance

Constructors

QueryInProgressError()

Properties

code ↔ int
getter/setter pairinherited-setteroverride-getter
hashCode → int
The hash code for this object.
no setterinherited
message ↔ String?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackTrace → StackTrace?
The stack trace at the point where this error was first thrown.
no setterinherited

Methods

byaction(String erraction) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited