FileInfo class

Represents information about image that will be used to upload

Annotations
  • @JsonSerializable.new()

Constructors

FileInfo({String? name, String? url, String? mimeType, int? fileSize, File? file, Uint8List? fileBytes})
FileInfo.fromBytes({required String? name, required Uint8List? fileBytes, required String? mimeType, File? file = null})
FileInfo.fromData({required String? name, required File? file, required String? mimeType})
FileInfo.fromJson(Map<String, dynamic> json)
factory
FileInfo.fromUrl({required String? url, String? mimeType, int? fileSize, String? name})

Properties

file → File?
file data
final
fileBytes ↔ Uint8List?
file bytes
getter/setter pair
fileSize ↔ int?
file size
getter/setter pair
hasBinary → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
hasSource → bool
no setter
mimeType → String?
mime file type
final
name → String?
name of this file
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url ↔ String?
url of this file
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited