MessageMetaArray class

An object represents message meta array.

Annotations
  • @JsonSerializable.new()

Constructors

MessageMetaArray({required String key, List<String> value = const []})
MessageMetaArray.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
key → String
Meta array key
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → List<String>
Meta array values
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited