ChannelChangeLogsResponse class

Inheritance
Annotations
  • @JsonSerializable.new(createToJson: false)

Constructors

ChannelChangeLogsResponse({required List<GroupChannel> updatedChannels, required List<String> deletedChannelUrls, required bool hasMore, String? next})

Properties

deletedChannelUrls → List<String>
final
hashCode → int
The hash code for this object.
no setterinherited
hasMore → bool
final
next → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updatedChannels → List<GroupChannel>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → ChannelChangeLogsResponse