DoNotDisturbResponse class

Inheritance
Annotations
  • @JsonSerializable.new(createToJson: false)

Constructors

DoNotDisturbResponse({required bool enabled, int? startHour, int? startMin, int? endHour, int? endMin, String? timezone})

Properties

enabled → bool
final
endHour → int?
final
endMin → int?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startHour → int?
final
startMin → int?
final
timezone → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → DoNotDisturbResponse