MessageSearchQueryResponse class

Inheritance
Annotations
  • @JsonSerializable.new(createToJson: false)

Constructors

MessageSearchQueryResponse({List<BaseMessage> results = const [], String? next, bool hasNext = false, int totalCount = -1})
MessageSearchQueryResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
hasNext ↔ bool
getter/setter pair
next ↔ String?
getter/setter pair
results ↔ List<BaseMessage>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalCount ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited