MuteInfoResponse class

Inheritance
Annotations
  • @JsonSerializable.new(createToJson: false)

Constructors

MuteInfoResponse({required bool isMuted, String? description, int? startAt, int? endAt, int? remainingDuration})

Properties

description → String?
final
endAt → int?
final
hashCode → int
The hash code for this object.
no setterinherited
isMuted → bool
final
remainingDuration → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startAt → int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → MuteInfoResponse