ThreadedMessageResponse class

Inheritance

Constructors

ThreadedMessageResponse({required BaseMessage parentMessage, required List<BaseMessage> replies})

Properties

hashCode → int
The hash code for this object.
no setterinherited
parentMessage ↔ BaseMessage
getter/setter pair
replies ↔ List<BaseMessage>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited