UploadResponse class

Inheritance
Annotations
  • @JsonSerializable.new(createToJson: false)

Constructors

UploadResponse({required String url, required List thumbnails, required bool requireAuth, required int fileSize})

Properties

fileSize → int
final
hashCode → int
The hash code for this object.
no setterinherited
requireAuth → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thumbnails → List
final
url → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → UploadResponse