UnreadItemCount class

Annotations
  • @JsonSerializable.new(createToJson: false)

Constructors

UnreadItemCount({int? groupChannelInvitationCount, int? groupChannelUnreadMentionCount, int? groupChannelUnreadMessageCount, int? superGroupChannelInvitationCount, int? superGroupChannelUnreadMentionCount, int? superGroupChannelUnreadMessageCount, int? nonSuperGroupChannelInvitationCount, int? nonSuperGroupChannelUnreadMentionCount, int? nonSuperGroupChannelUnreadMessageCount})

Properties

groupChannelInvitationCount → int?
Count of invitation of all group channels
final
groupChannelUnreadMentionCount → int?
Count of unread mention in all of group channels
final
groupChannelUnreadMessageCount → int?
Count of unread message in all of group channels
final
hashCode → int
The hash code for this object.
no setterinherited
nonSuperGroupChannelInvitationCount → int?
Count of invitation of all non super group channels
final
nonSuperGroupChannelUnreadMentionCount → int?
Count of unread mention in all of non super group channels
final
nonSuperGroupChannelUnreadMessageCount → int?
Count of unread message in all of non super group channels
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
superGroupChannelInvitationCount → int?
Count of invitation of all super group channels
final
superGroupChannelUnreadMentionCount → int?
count of unread mention in all of super group channels
final
superGroupChannelUnreadMessageCount → int?
Count of unread message in all of non super group channels
final

Methods

has(List<UnreadItemKey> keys) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → UnreadItemCount