LoginEvent class

Represents login event

Inheritance
Annotations
  • @JsonSerializable.new(createToJson: false)

Constructors

LoginEvent({String? ekey, String? newKey, String? key, required int loginTimestamp, required ReconnectConfiguration reconnectConfiguration, required int pingInterval, required int watchdogInterval, int? maxUnreadCountOnSuperGroup})
LoginEvent.fromJson(Map<String, dynamic> json)
factory

Properties

appInfo ↔ AppInfo
getter/setter pair
ekey → String?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
key → String?
finalinherited
loginTimestamp → int
final
maxUnreadCountOnSuperGroup → int?
final
newKey → String?
finalinherited
pingInterval → int
final
reconnectConfiguration → ReconnectConfiguration
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionKey → String
no setterinherited
user ↔ User
getter/setter pair
watchdogInterval → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited