MessageEvent class

Represents message event

Inheritance
Annotations
  • @JsonSerializable.new(createToJson: false)

Constructors

MessageEvent({required int messageId, required ChannelType channelType, required String channelUrl, bool forceUpdateLastMessage = false, bool silent = false, Sender? sender, String? requestId, MentionType? mentionType, List<User>? mentionedUsers, List<Thumbnail>? thumbnails, Map<String, dynamic>? oldValues})
MessageEvent.fromJson(Map<String, dynamic> json)
factory

Properties

channelType → ChannelType
final
channelUrl → String
final
forceUpdateLastMessage → bool
final
hashCode → int
The hash code for this object.
no setterinherited
mentionedUsers → List<User>?
final
mentionType → MentionType?
final
messageId → int
final
oldValues → Map<String, dynamic>?
final
requestId ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sender → Sender?
final
silent → bool
final
thumbnails → List<Thumbnail>?
final

Methods

hasChangedMentionType() → MentionType?
mentionedContains(User user) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
previousMentionedContains(User user) → bool
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited