UserEvent class

Represents user event

Implemented types
Annotations
  • @JsonSerializable.new(createToJson: false)

Constructors

UserEvent({required UserEventCategory category, required Map<String, dynamic> data, required int ts})

Properties

blockee → User
no setter
blocker → User
no setter
category ↔ UserEventCategory
getter/setter pair
data → Map<String, dynamic>
final
friendDiscoveries → List<User>
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
ts ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → UserEvent