DeliveryStatus class

Represents delivery status of channel

Implemented types
Available extensions
Annotations
  • @JsonSerializable.new(createToJson: false)

Constructors

DeliveryStatus({required String channelUrl, Map<String, int> updatedDeliveryReceipt = const {}})
DeliveryStatus.fromJson(Map<String, dynamic> json)
factory

Properties

channelUrl → String
final
dirty ↔ bool
getter/setter pairoverride
hashCode → int
The hash code for this object.
no setterinherited
key → String
no setteroverride
primaryKey → String
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updatedDeliveryReceipt ↔ Map<String, int>
getter/setter pair

Methods

copyWith(dynamic others) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeFromCache() → void

Available on Cacheable, provided by the Operation extension

saveToCache() → void

Available on Cacheable, provided by the Operation extension

toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited