ReadStatus class

Represents read status of a User.

Implemented types
Available extensions
Annotations
  • @JsonSerializable.new(createToJson: false)

Constructors

ReadStatus({required String userId, required int timestamp, required String channelUrl, required ChannelType channelType})
ReadStatus.fromJson(Map<String, dynamic> json)
factory

Properties

channelType → ChannelType
Channel type for this read status
final
channelUrl → String
Channel url for this read status
final
dirty ↔ bool
getter/setter pairoverride
hashCode → int
The hash code for this object.
no setterinherited
key → String
no setteroverride
primaryKey → String
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp ↔ int
Latest read timestamps
getter/setter pair
userId → String
User's id
final

Methods

copyWith(dynamic others) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeFromCache() → void

Available on Cacheable, provided by the Operation extension

saveToCache() → void

Available on Cacheable, provided by the Operation extension

toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited