OGImage class

Represents open graph image information

Implemented types
Annotations
  • @JsonSerializable.new()

Constructors

OGImage({String? url, String? secureUrl, String? type, String? alt, int width = 0, int height = 0})
OGImage.fromJson(Map<String, dynamic> json)
factory

Properties

alt → String?
Description of what's in this image
final
hashCode → int
The hash code for this object.
no setterinherited
height → int
Image height
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secureUrl → String?
Image secure url
final
type → String?
Image type
final
url → String?
Image url
final
width → int
Image width
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited