OGMetaData class

Represents open graph information

Annotations
  • @JsonSerializable.new()

Constructors

OGMetaData({String? title, String? url, String? description, OGImage? defaultImage})
OGMetaData.fromJson(Map<String, dynamic> json)
factory

Properties

defaultImage → OGImage?
Open graph image
final
description → String?
Open graph description
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String?
Open graph title
final
url → String?
Open graph url
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited