ThreadInfoUpdateEvent class

Represents thread update information.

This object is returned through the event handler when a threaded reply is added or deleted. This object is needed to be applied to the parent message.

Implemented types
Annotations
  • @JsonSerializable.new(createToJson: false)

Constructors

ThreadInfoUpdateEvent({required ThreadInfo threadInfo, required int parentMessageId, required ChannelType channelType, required String channelUrl})
ThreadInfoUpdateEvent.fromJson(Map<String, dynamic> json)
factory

Properties

channelType → ChannelType
Type of the channel where threaded message belongs
final
channelUrl → String
Unique url of the channel where threaded message belongs
final
hashCode → int
The hash code for this object.
no setterinherited
parentMessageId → int
Unique id of the message that contains threaded information
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
threadInfo → ThreadInfo
Information about threaded message
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited