TypingStatus class

Represents typing status of a User

Implemented types
Available extensions

Constructors

TypingStatus({required ChannelType channelType, required String channelUrl, required User user, required int timestamp})

Properties

channelType ↔ ChannelType
getter/setter pair
channelUrl ↔ String
getter/setter pair
dirty ↔ bool
getter/setter pairoverride
hashCode → int
The hash code for this object.
no setterinherited
key → String
no setteroverride
primaryKey → String
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp ↔ int
getter/setter pair
user ↔ User
getter/setter pair

Methods

copyWith(dynamic others) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeFromCache() → void

Available on Cacheable, provided by the Operation extension

saveToCache() → void

Available on Cacheable, provided by the Operation extension

toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited