SessionManager class

Represents a object that responsible to handle session

Mixed-in types

Constructors

SessionManager()

Properties

accessToken → String?
no setter
appState → SendbirdState
no setterinherited
cmdManager → CommandManager
no setterinherited
errorFunc ↔ Function
getter/setter pair
eventManager → EventManager
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isRefreshingKey ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sdk → SendbirdSdkInternal
no setterinherited
sessionUpdateCompleters ↔ List<Completer>
getter/setter pair
successFunc ↔ Future Function(String)
getter/setter pair
webSocket → WebSocketClient?
no setterinherited

Methods

cleanUp() → void
flushResultCompleters(SBError error) → void
getEKey() → String?
Get current eKey
getSessionKey() → Future<String?>
Get current sessionKey from prefs
getUserId() → String?
Get userId associate with this user session
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setAccessToken(String? accessToken) → void
setEKey(String? eKey) → void
Set a eKey that will be used to access file url where authorization is required
setSessionKey(String? sessionKey) → Future<void>
Set a sessionKey that will be used for SDK globally
setSessionKeyPath(String path) → void
Set a path to store session key. Recommend to set your own path to store this path for security purpose
setUserId(String userId) → void
Set a userId associate with this user session
setUserIdKeyPath(String path) → void
Set a path to store user id key. Recommend to set your own path to store this path for security purpose
toString() → String
A string representation of this object.
inherited
updateSession() → Future<void>

Operators

operator ==(Object other) → bool
The equality operator.
inherited