BaseMessageParams class

Represents base class for message parameters.

Implementers

Constructors

BaseMessageParams({String? data, String? customType, PushNotificationDeliveryOption pushOption = PushNotificationDeliveryOption.normal, List<MessageMetaArray>? metaArrays, MentionType? mentionType, List<String>? mentionedUserIds, int? parentMessageId, bool replyToChannel = false, List<User>? mentionedUsers, bool isPinnedMessage = false})
BaseMessageParams.withMessage(BaseMessage message, {bool? deepCopy})

Properties

customType ↔ String?
Customize message's type to filter
getter/setter pair
data ↔ String?
Message data. The default value is null
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isPinnedMessage ↔ bool
Pinned Message
getter/setter pair
mentionedUserIds ↔ List<String>?
Mention to specific users. If sends a message with this field, the message will be arrived to mentioned users.
getter/setter pair
mentionedUsers ↔ List<User>?
The list of users who was mentioned together with this message.
getter/setter pair
mentionType ↔ MentionType?
Mention type
getter/setter pair
metaArrays ↔ List<MessageMetaArray>?
Meta array with keys and values
getter/setter pair
parentMessageId ↔ int?
The unique ID of a parent message. A parent message is a message that has a thread of replies. If the message sent through the BaseChannel.sendUserMessage or BaseChannel.sendFileMessage method is a parent message, the value of this property is 0. If the message is a reply to a parent message, the value is the message ID of the parent message.
getter/setter pair
pushOption ↔ PushNotificationDeliveryOption
The push notification delivery option that determines how to deliver the push notification when sending a user or a file message.
getter/setter pair
replyToChannel ↔ bool
Allow Reply to Channel The default is false
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited