FileMessageParams class

An object consists a set of parameters for file message.

Inheritance

Constructors

FileMessageParams.withFile(File file, {String? name})
NOTE: Not supported for Web
FileMessageParams.withFileBytes(Uint8List data, {String? name, String? fileExtensionType})
FileMessageParams.withMessage(FileMessage fileMessage, {bool? deepCopy})
NOTE: should use this constructor when updating message
FileMessageParams.withUrl(String fileUrl, {String? mimeType, int? size, String? name})

Properties

customType ↔ String?
Customize message's type to filter
getter/setter pairinherited
data ↔ String?
Message data. The default value is null
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
isPinnedMessage ↔ bool
Pinned Message
getter/setter pairinherited
mentionedUserIds ↔ List<String>?
Mention to specific users. If sends a message with this field, the message will be arrived to mentioned users.
getter/setter pairinherited
mentionedUsers ↔ List<User>?
The list of users who was mentioned together with this message.
getter/setter pairinherited
mentionType ↔ MentionType?
Mention type
getter/setter pairinherited
metaArrays ↔ List<MessageMetaArray>?
Meta array with keys and values
getter/setter pairinherited
parentMessageId ↔ int?
The unique ID of a parent message. A parent message is a message that has a thread of replies. If the message sent through the BaseChannel.sendUserMessage or BaseChannel.sendFileMessage method is a parent message, the value of this property is 0. If the message is a reply to a parent message, the value is the message ID of the parent message.
getter/setter pairinherited
pushOption ↔ PushNotificationDeliveryOption
The push notification delivery option that determines how to deliver the push notification when sending a user or a file message.
getter/setter pairinherited
replyToChannel ↔ bool
Allow Reply to Channel The default is false
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thumbnailSizes ↔ List<Size>?
Thumbnail sizes. This parameter is the array of Size and works for image file only
getter/setter pair
uploadFile ↔ FileInfo
Binary file data.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited