MessageChangeLogParams class

An object consists a set of parameters to retrieve message's change log

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

MessageChangeLogParams()

Properties

hashCode → int
The hash code for this object.
no setterinherited
includeMetaArray ↔ bool
Determines whether to include the metaarray information of the messages in the results. default value is false
getter/setter pairinherited
includeParentMessageInfo ↔ bool
Determines wheter to include parent message info in the results
getter/setter pairoverride
includeParentMessageText ↔ bool?
Determines whether to include the parent message text in the results when the messages are replies in a thread. If the type of the parent message is UserMessage the value is a message. If it is FileMessage, the value is the name of the uploaded file. default value is false
getter/setter pairoverride
includeReactions ↔ bool
Determines whether to include the reactions to the messages in the results. default value is false
getter/setter pairoverride
includeReplies ↔ bool?
Determines whether to include the reactions to the messages in the results. default value is false
getter/setter pairoverride
includeThreadInfo ↔ bool
Determines whether to include the thread information of the messages in the results when the results contain root messages. default value is false
getter/setter pairoverride
replyType ↔ ReplyType?
Determines message's reply type
getter/setter pairoverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited