MessageListParams class

An object consists a set of parameters to retrieve list of messages.

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

MessageListParams()

Properties

customType ↔ String?
Restricts the search scope only to retrieve the messages with the specified custom message type.
getter/setter pair
customTypes ↔ List<String>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
includeMetaArray ↔ bool
Determines whether to include the metaarray information of the messages in the results. default value is false
getter/setter pairinherited
includeParentMessageInfo ↔ bool
Determines wheter to include parent message information
getter/setter pairoverride
includeParentMessageText ↔ bool?
Determines whether to include the parent message text in the results when the messages are replies in a thread. If the type of the parent message is UserMessage the value is a message. If it is FileMessage, the value is the name of the uploaded file. default value is false
getter/setter pairinherited
includeReactions ↔ bool
Determines whether to include the reactions to the messages in the results. default value is false
getter/setter pairinherited
includeReplies ↔ bool?
Determines whether to include the reactions to the messages in the results. default value is false
getter/setter pairinherited
includeThreadInfo ↔ bool
Determines whether to include the thread information of the messages in the results when the results contain root messages. default value is false
getter/setter pairinherited
isInclusive ↔ bool
Determines whether to include the messages with the matching timestamp or message ID in the results.
getter/setter pair
messageType ↔ MessageTypeFilter
Restricts the search scope only to retrieve the messages with the specified message type.
getter/setter pair
nextResultSize ↔ int
The number of messages to retrieve that were sent after the specified timestamp or message ID.
getter/setter pair
previousResultSize ↔ int
The number of messages to retrieve that were sent before the specified timestamp or message ID.
getter/setter pair
replyType ↔ ReplyType?
Determines message's reply type
getter/setter pairoverride
reverse ↔ bool
Determines whether to sort the retrieved messages in reverse order. If false, the results are in ascending order.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
senderIds ↔ List<String>?
Restricts the search scope only to retrieve the messages sent by the users with the specified user IDs.
getter/setter pair
showSubChannelMessagesOnly ↔ bool
Determines whether to retrieve sub channel messages on Dynamic Partitioning. This property is only working for OpenChannel
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited