PollCreateParams class

Annotations
  • @JsonSerializable.new()

Constructors

PollCreateParams({required String title, required List<String> options, PollData? data, bool? allowUserSuggestion, bool? allowMultipleVotes, int closeAt = -1})

Properties

allowMultipleVotes ↔ bool?
Whether to allow multiple vote casting. Default is NO
getter/setter pair
allowUserSuggestion ↔ bool?
Whether to allow user-suggested options. Default is false
getter/setter pair
closeAt ↔ int
Unix timestamp at which the poll will close (millisecond)
getter/setter pair
data ↔ PollData?
An additional text to accompany the poll.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
options ↔ List<String>
Possible options for which a user can vote
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title ↔ String
Title of a poll
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited