ScheduledFileMessageUpdateParams class

Annotations
  • @JsonSerializable.new()

Constructors

ScheduledFileMessageUpdateParams({String? url, String? fileName, int? fileSize, String? fileType, List? thumbnails, int? scheduledAt, String? customType, String? data, bool? requireAuth, bool? sendPush, String? mentionType, List? mentionedUserIds, bool? isSilent, bool? markAsRead, Map? sortedMetaarray, String? dedupId, String? apnsBundleId, PushTriggerOption? pushOption, AppleCriticalAlertOptions? appleCriticalAlertOptions, String? reqId})

Properties

apnsBundleId ↔ String?
Specifies the bundle ID of the client app in order to send a push notification to iOS devices.
getter/setter pair
appleCriticalAlertOptions ↔ AppleCriticalAlertOptions?
Options that support Apple critical alerts and checks whether the message is a critical alert.
getter/setter pair
customType ↔ String?
Specifies a custom message type which is used for message grouping. The length is limited to 128 characters.
getter/setter pair
data ↔ String?
Specifies additional message information such as custom font size, font type or JSON formatted string.
getter/setter pair
dedupId ↔ String?
Specifies the unique message ID created by other system.
getter/setter pair
fileName ↔ String?
Name of file which is specified by the url property.
getter/setter pair
fileSize ↔ int?
Size of file which is specified by the url property.
getter/setter pair
fileType ↔ String?
If the file property is used for file upload, this property is automatically specified by Sendbird server.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isSilent ↔ bool?
Determines whether to send a message without updating some of the channel properties.
getter/setter pair
markAsRead ↔ bool?
Determines whether to mark the message as read for the sender.
getter/setter pair
mentionedUserIds ↔ List?
Specifies an array of one or more IDs of the users who will get a notification for the message.
getter/setter pair
mentionType ↔ String?
Specifies the mentioning method which indicates the user scope who will get a notification for the message.
getter/setter pair
pushOption ↔ PushTriggerOption?
default, suppress, force
getter/setter pair
reqId ↔ String?
Additional ID which is sent from the SDK.
getter/setter pair
requireAuth ↔ bool?
Determines whether or not the file in the message and generated thumbnail images can be only accessed by the users within the application who are participating in the same open channel, or who are the members of the same group channel.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scheduledAt ↔ int?
The time to send the message, in Unix milliseconds format. The messages are scheduled in minutes The term between current time and scheduledAt should be between 5 minutes (depending on the app attribute minimum_interval_for_scheduling) and 30 days
getter/setter pair
sendPush ↔ bool?
Determines whether to send a push notification for the message to the members of the channel
getter/setter pair
sortedMetaarray ↔ Map?
Specifies a JSON object of one or more key-values items which store additional message information.
getter/setter pair
thumbnails ↔ List?
Specifies an array of one or more URLs of the external thumbnail images which are generated from the image which is specified by the url property.
getter/setter pair
url ↔ String?
Specifies the URL of the file which is hosted on the server of your own or other external third party companies.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited