UserMessageParams class

An object consists a set of parameters to create/update user message.

Inheritance

Constructors

UserMessageParams({required String message, int? pollId, List<String>? targetLanguages, String? data, String? customType, PushNotificationDeliveryOption pushOption = PushNotificationDeliveryOption.normal, bool isChannelMention = false, MentionType? mentionType, List<String>? mentionedUserIds, List<MessageMetaArray>? metaArrays, bool? replyToChannel, Map<String, dynamic>? extendedMessage, bool isPinnedMessage = false})
UserMessageParams.withMessage(UserMessage userMessage, {bool? deepCopy})

Properties

customType ↔ String?
Customize message's type to filter
getter/setter pairinherited
data ↔ String?
Message data. The default value is null
getter/setter pairinherited
extendedMessage ↔ Map<String, dynamic>?
Message Template
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isChannelMention ↔ bool
getter/setter pair
isPinnedMessage ↔ bool
Pinned Message
getter/setter pairinherited
mentionedUserIds ↔ List<String>?
Mention to specific users. If sends a message with this field, the message will be arrived to mentioned users.
getter/setter pairinherited
mentionedUsers ↔ List<User>?
The list of users who was mentioned together with this message.
getter/setter pairinherited
mentionType ↔ MentionType?
Mention type
getter/setter pairinherited
message ↔ String
Text message
getter/setter pair
metaArrays ↔ List<MessageMetaArray>?
Meta array with keys and values
getter/setter pairinherited
parentMessageId ↔ int?
The unique ID of a parent message. A parent message is a message that has a thread of replies. If the message sent through the BaseChannel.sendUserMessage or BaseChannel.sendFileMessage method is a parent message, the value of this property is 0. If the message is a reply to a parent message, the value is the message ID of the parent message.
getter/setter pairinherited
pollId ↔ int?
Unique ID for a poll
getter/setter pair
pushOption ↔ PushNotificationDeliveryOption
The push notification delivery option that determines how to deliver the push notification when sending a user or a file message.
getter/setter pairinherited
replyToChannel ↔ bool
Allow Reply to Channel The default is false
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetLanguages ↔ List<String>
The target languages that a message will be translated into
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited