QueryBase class abstract

Abstract class for query

Implementers

Constructors

QueryBase()

Properties

hashCode → int
The hash code for this object.
no setterinherited
hasNext ↔ bool
True if query has next items to be queried
getter/setter pair
limit ↔ int
number of item per executing loadNext
getter/setter pair
loading ↔ bool
True if query is loading
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
token ↔ String?
token for next query
getter/setter pair

Methods

loadNext() → Future<List>
Load next items asynchronously
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited