PreviousMessageListQuery class

A query object to retrieve previous messages

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

PreviousMessageListQuery({required ChannelType channelType, required String channelUrl})

Properties

channelType ↔ ChannelType
Channel type
getter/setter pair
channelUrl ↔ String
Channel url
getter/setter pair
customTypesFilter ↔ List<String>
Restricts the search scope only to retrieve the messages with the specified custom message type.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hasNext ↔ bool
True if query has next items to be queried
getter/setter pairinherited
includeMetaArray ↔ bool
Determines whether to include the metaarray information of the messages in the results. default value is false
getter/setter pair
includeParentMessageInfo ↔ bool
Determines whether to include current message's parent information
getter/setter pair
includeParentMessageText ↔ bool?
Determines whether to include the parent message text in the results when the messages are replies in a thread. If the type of the parent message is UserMessage the value is a message. If it is FileMessage, the value is the name of the uploaded file. default value is false
getter/setter pair
includeReactions ↔ bool
Determines whether to include the reactions to the messages in the results. default value is false
getter/setter pair
includeReplies ↔ bool?
Determines whether to include the reactions to the messages in the results. default value is false
getter/setter pair
includeThreadInfo ↔ bool
Determines whether to include the thread information of the messages in the results when the results contain root messages. default value is false
getter/setter pair
limit ↔ int
number of item per executing loadNext
getter/setter pairinherited
loading ↔ bool
True if query is loading
getter/setter pairinherited
messageTypeFilter ↔ MessageTypeFilter
Restricts the search scope only to retrieve the messages with the specified message type.
getter/setter pair
replyType ↔ ReplyType
Determines message's reply type
getter/setter pair
reverse ↔ bool
Determines whether to sort the retrieved messages in reverse order. If false, the results recieves the oldest messages first.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
senderIdsFilter ↔ List<String>
Restricts the search scope only to retrieve the messages sent by the users with the specified user IDs.
getter/setter pair
showSubChannelMessagesOnly ↔ bool
Determines whether to retrieve sub channel messages on Dynamic Partitioning. This property is only working for OpenChannel
getter/setter pair
token ↔ String?
token for next query
getter/setter pairinherited

Methods

loadNext() → Future<List<BaseMessage>>
Load next items asynchronously
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited