MessageSearchQuery class

A query object to search messages

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

MessageSearchQuery({required String keyword})

Properties

advancedQuery ↔ bool
True if keyword contains advanced query style text
getter/setter pair
afterIndex ↔ String?
Index for search after
getter/setter pair
beforeIndex ↔ String?
Index for search before
getter/setter pair
channelCustomType ↔ String?
Channel custom type to filter
getter/setter pair
channelUrl ↔ String?
Channel url
getter/setter pair
exactMatch ↔ bool
true to be exact match for keyword
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hasNext ↔ bool
True if query has next items to be queried
getter/setter pairinherited
keyword ↔ String
Keyword to search
getter/setter pair
limit ↔ int
number of item per executing loadNext
getter/setter pairinherited
loading ↔ bool
True if query is loading
getter/setter pairinherited
messageTimestampFrom ↔ int?
Timestamp for search from
getter/setter pair
messageTimestampTo ↔ int?
Timestamp for search to
getter/setter pair
order ↔ MessageSearchQueryOrder
Message search result sort order
getter/setter pair
reverse ↔ bool
Determines whether to sort the retrieved messages in reverse order.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetFields ↔ List<String>
List of strings to look up message's data field to get matched
getter/setter pair
targetUserIds ↔ List<String>
List of user ids to filter out resultda
getter/setter pair
token ↔ String?
token for next query
getter/setter pairinherited

Methods

loadNext() → Future<List<BaseMessage>>
Load next items asynchronously
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited