MutedUserListQuery class

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

MutedUserListQuery({required ChannelType channelType, required String channelUrl})

Properties

channelType ↔ ChannelType
Channel type related to this query
getter/setter pair
channelUrl ↔ String
Channel url related to this query
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hasNext ↔ bool
True if query has next items to be queried
getter/setter pairinherited
limit ↔ int
number of item per executing loadNext
getter/setter pairinherited
loading ↔ bool
True if query is loading
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
token ↔ String?
token for next query
getter/setter pairinherited

Methods

loadNext() → Future<List<RestrictedUser>>
Load next items asynchronously
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited