ApplicationUserListQuery class

A query object to retrieve list of user on current application.

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

ApplicationUserListQuery({String? metaDataKey, List<String>? metaDataValues, String? nicknameStartsWith})

Properties

channelType ↔ ChannelType?
Channel type related to this query
getter/setter pairinherited
channelUrl ↔ String?
Channel url related to this query
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
hasNext ↔ bool
True if query has next items to be queried
getter/setter pairinherited
limit ↔ int
number of item per executing loadNext
getter/setter pairinherited
loading ↔ bool
True if query is loading
getter/setter pairinherited
metaDataKey ↔ String?
Filters users who have this meta data key.
getter/setter pair
metaDataValues ↔ List<String>?
Filters users who have this meta data values.
getter/setter pair
nicknameStartsWith ↔ String?
Filters users whose nicknames start with the this value
getter/setter pair
queryType ↔ UserListQueryType
Query type
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
token ↔ String?
token for next query
getter/setter pairinherited
userIds ↔ List<String>?
Filter for list of user ids
getter/setter pairinherited

Methods

loadNext() → Future<List<User>>
Load next items asynchronously
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited