ApiRequest class abstract

Implementers

Constructors

ApiRequest({String? token, bool bypassAuth = false, String? userId})

Properties

body ↔ Map<String, dynamic>
getter/setter pair
bypassAuth ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
headers ↔ Map<String, String>
getter/setter pair
isMultipart ↔ bool
getter/setter pair
method ↔ Method
getter/setter pair
progress ↔ OnUploadProgressCallback?
getter/setter pair
queryParams ↔ Map<String, dynamic>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → SendbirdState
final
token ↔ String?
getter/setter pair
url ↔ String
getter/setter pair
userId ↔ String?
getter/setter pair
version ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
response(Map<String, dynamic> res) → Future
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited