WsEvent class abstract

Constructors

WsEvent({String? requestId, Map<String, dynamic> payload = const {}, ChannelEventCategory? category})

Properties

category → ChannelEventCategory?
final
cmd ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
payload ↔ Map<String, dynamic>
getter/setter pair
requestId ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

handleEvent(SendbirdSdkInternal sdk) → Future
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited