WsRequest class abstract

Implementers

Constructors

WsRequest({String? requestId})

Properties

cmd ↔ String
getter/setter pair
encoded → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
isAckRequired → bool
no setter
payload ↔ Map<String, dynamic>
getter/setter pair
requestId ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited