ChannelCacheUnit class

Implemented types

Constructors

ChannelCacheUnit()

Properties

cachedMetaData ↔ CachedDataMap<String>?
getter/setter pair
channel ↔ BaseChannel?
getter/setter pair
deliveryStatus ↔ DeliveryStatus?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
readStatus ↔ Map<String, ReadStatus>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
typingStatus ↔ Map<String, TypingStatus>
getter/setter pair

Methods

delete<T extends Cacheable>({String? key, Cacheable? data}) → void
override
find<T extends Cacheable>({String? key}) → T?
override
insert(Cacheable data) → void
override
markAsDirty() → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited