ApiClient class

Constructors

ApiClient({SendbirdState? state, String? appId, String? token})

Properties

appId ↔ String?
getter/setter pair
baseUrl ↔ String?
getter/setter pair
client ↔ HttpClient
getter/setter pair
currentUserId ↔ String?
getter/setter pair
errorStream → Stream
no setter
hashCode → int
The hash code for this object.
no setterinherited
headers ↔ Map<String, String>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionKey ↔ String?
getter/setter pair
state ↔ SendbirdState?
getter/setter pair
token ↔ String?
getter/setter pair

Methods

cancelUploadingFile(String requestId) → bool
cleanUp() → void
initialize({String? appId, String? token, String? baseUrl, Map<String, String>? headers}) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
send<T>(ApiRequest request) → Future<T>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited