HttpClient class

Constructors

HttpClient(SendbirdState? state)

Properties

appId ↔ String?
getter/setter pair
baseUrl ↔ String?
getter/setter pair
bypassAuth ↔ bool
getter/setter pair
errorController ↔ StreamController
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
headers ↔ Map<String, String>
getter/setter pair
isLocal ↔ bool
getter/setter pair
request ↔ MultipartRequest?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ SendbirdState?
getter/setter pair
token ↔ String?
getter/setter pair
uploadRequests ↔ Map<String, MultipartRequest>
getter/setter pair

Methods

cacnel() → void
cancelUploadRequest(String requestId) → bool
cleanUp() → void
commonHeaders() → Map<String, String>
delete({required String url, Map<String, dynamic> queryParams = const {}, Map<String, dynamic> body = const {}, Map<String, String> headers = const {}}) → Future
get({required String url, Map<String, dynamic>? queryParams, Map<String, String>? headers}) → Future
multipartRequest({required Method method, required String url, Map<String, dynamic>? body, Map<String, dynamic>? queryParams, Map<String, String>? headers, OnUploadProgressCallback? progress}) → Future
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch({required String url, Map<String, dynamic>? queryParams, Map<String, dynamic>? body, Map<String, String>? headers}) → Future
post({required String url, Map<String, dynamic> queryParams = const {}, Map<String, dynamic> body = const {}, Map<String, String> headers = const {}}) → Future
put({required String url, Map<String, dynamic> queryParams = const {}, Map<String, dynamic> body = const {}, Map<String, String> headers = const {}}) → Future
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited