WebSocketClient class

Constructors

WebSocketClient({required OnWSConnect onConnect, required OnWSDisconnect onDisconnect, required OnWSData onData, required OnWSError onError})

Properties

connectionState → ConnectionState
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

close({int code = WebSocketStatus.normalClosure, String reason = ''}) → Future<bool>
connect(String url) → Future<void>
isConnected() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onReceiveData(dynamic evt) → void
onReceiveDone() → void
onReceiveError(Object error) → void
send(String data) → void
setInterval(int seconds) → void
setWatchdogInterval(int seconds) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited