AsyncTask<T> class

Implemented types

Constructors

AsyncTask({required Future func(T), required T arg, dynamic onCancel()?})

Properties

arg ↔ T
getter/setter pair
func ↔ Future Function(T)
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
onCancel ↔ dynamic Function()?
getter/setter pairoverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited