IsolateMaster class

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

didInitialize() → void
handleError(String action) → void
handleMessage(dynamic action) → void
initialize() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pingCount() → int
pingLast() → DateTime
sendToMaster(dynamic action) → void
sendToSlave(dynamic action) → void
shutdown() → FutureOr<void>
toString() → String
A string representation of this object.
inherited
waitStatus(int msecs, [IsoBridgeStatus ref = IsoBridgeStatus.none]) → FutureOr<IsoBridgeStatus>

Operators

operator ==(Object other) → bool
The equality operator.
inherited